# Materials

## Base Materials
::: fdtdx.objects.material.UniformMaterial
Base class for materials with uniform electromagnetic properties.

::: fdtdx.objects.material.NoMaterial
Non-interacting material that preserves existing properties.

::: fdtdx.objects.material.SimulationVolume
Background material defining simulation environment properties.

::: fdtdx.objects.material.Substrate
Material for modeling substrate layers.

::: fdtdx.objects.material.WaveGuide
Material for optical waveguide structures.
